@@ -27,9 +27,6 @@ $dbh->disconnect;
 __PACKAGE__->__dbfile($dbfile);
 
 __PACKAGE__->config(
-    'Catalyst::Plugin::AutoCRUD' => {
-        extjs2 => '/javascript/extjs-2',
-    },
     'Model::AutoCRUD::DBIC' => {
         schema_class => 'TestApp::Schema',
         connect_info => ["dbi:SQLite:dbname=$dbfile", '', ''],
